==> aws_cdk.aws_lambda_python_alpha-2.11.0a0-py3-none-any.whl: package/.warnings.jsii.js <==
function _aws_cdk_aws_lambda_python_alpha_PythonFunction(p) {
}
function _aws_cdk_aws_lambda_python_alpha_PythonLayerVersion(p) {
}
function _aws_cdk_aws_lambda_python_alpha_PythonFunctionProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.bundling))
        _aws_cdk_aws_lambda_python_alpha_BundlingOptions(p.bundling);
    if (!visitedObjects.has(p.events))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_lambda_IEventSource(p.events);
    if (!visitedObjects.has(p.initialPolicy))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_iam_PolicyStatement(p.initialPolicy);
    if (!visitedObjects.has(p.layers))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_lambda_ILayerVersion(p.layers);
    if (!visitedObjects.has(p.securityGroups))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_ec2_ISecurityGroup(p.securityGroups);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_lambda_python_alpha_PythonLayerVersionProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.bundling))
        _aws_cdk_aws_lambda_python_alpha_BundlingOptions(p.bundling);
    if (!visitedObjects.has(p.compatibleArchitectures))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_lambda_Architecture(p.compatibleArchitectures);
    if (!visitedObjects.has(p.compatibleRuntimes))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_lambda_Runtime(p.compatibleRuntimes);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_lambda_python_alpha_BundlingOptions(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_lambda_python_alpha_PythonFunction, _aws_cdk_aws_lambda_python_alpha_PythonLayerVersion, _aws_cdk_aws_lambda_python_alpha_PythonFunctionProps, _aws_cdk_aws_lambda_python_alpha_PythonLayerVersionProps, _aws_cdk_aws_lambda_python_alpha_BundlingOptions };
module.exports.DeprecationError = DeprecationError;

==> aws_cdk.aws_lambda_python_alpha-2.19.0a0-py3-none-any.whl: package/.warnings.jsii.js <==
function _aws_cdk_aws_lambda_python_alpha_PythonFunction(p) {
}
function _aws_cdk_aws_lambda_python_alpha_PythonFunctionProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.bundling))
        _aws_cdk_aws_lambda_python_alpha_BundlingOptions(p.bundling);
    if (!visitedObjects.has(p.events))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_lambda_IEventSource(p.events);
    if (!visitedObjects.has(p.initialPolicy))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_iam_PolicyStatement(p.initialPolicy);
    if (!visitedObjects.has(p.layers))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_lambda_ILayerVersion(p.layers);
    if (!visitedObjects.has(p.securityGroups))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_ec2_ISecurityGroup(p.securityGroups);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_lambda_python_alpha_PythonLayerVersion(p) {
}
function _aws_cdk_aws_lambda_python_alpha_PythonLayerVersionProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.bundling))
        _aws_cdk_aws_lambda_python_alpha_BundlingOptions(p.bundling);
    if (!visitedObjects.has(p.compatibleArchitectures))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_lambda_Architecture(p.compatibleArchitectures);
    if (!visitedObjects.has(p.compatibleRuntimes))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_lambda_Runtime(p.compatibleRuntimes);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_lambda_python_alpha_BundlingOptions(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_lambda_python_alpha_PythonFunction, _aws_cdk_aws_lambda_python_alpha_PythonFunctionProps, _aws_cdk_aws_lambda_python_alpha_PythonLayerVersion, _aws_cdk_aws_lambda_python_alpha_PythonLayerVersionProps, _aws_cdk_aws_lambda_python_alpha_BundlingOptions };
module.exports.DeprecationError = DeprecationError;
